/*
** Module   : MouseWidgetAction.java
** Abstract : Definition of a generic mouse action, to be applied to a widget.
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20140805 Created initial version.
** 002 GES 20150501 Moved to a more generic package.
*/
package com.goldencode.p2j.ui.client.gui.driver;

// this usage of AWT events is intentional, they are being used separately from the AWT/Swing
// event model; no other AWT/Swing usage is occurring in this class
import java.awt.event.*;

import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * A generic action which can be applied to a specified widget, via mouse.
 */
abstract class MouseWidgetAction
extends MouseAdapter
{
   /** The widget associated with this action. */
   protected final Widget<GuiOutputManager> widget;
   
   /** The active GUI driver. */
   protected GuiDriver gd;
   
   /**
    * Create a new mouse action, for the specified widget.
    * 
    * @param    wid
    *           The widget ID.
    */
   @SuppressWarnings("unchecked")
   public MouseWidgetAction(int wid)
   {
      widget = (Widget<GuiOutputManager>) OutputManager.resolveWidget(wid);

      gd = (GuiDriver) OutputManager.getDriver();
   }
}
